#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.1.0.0
visibility:           public
id:                   hspec-hedgehog-0.1.0.0-FmU0giJceiI17FnzvO9t2G
key:                  hspec-hedgehog-0.1.0.0-FmU0giJceiI17FnzvO9t2G
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  9e5fb357d5024bd9a8fd92b24a4a4635
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.1.0.0-FmU0giJceiI17FnzvO9t2G
depends:
    QuickCheck-2.15.0.1-FUcewYgFPTwGfyjnEpPlTz base-4.18.2.1
    hedgehog-1.5-4j7cgUUYiN18SGNErD2NGw
    hspec-2.11.7-7U6fx3dsaNQ7EcGdmqSFJ7
    hspec-core-2.11.7-27IPsOpYwqA3fHjRVZCfqo
    splitmix-0.1.3-CI0AeQd6dWk9lg8Jn80fH5

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

